-- CA1005A.ADA

--                             Grant of Unlimited Rights
--
--     Under contracts F33600-87-D-0337, F33600-84-D-0280, MDA903-79-C-0687,
--     F08630-91-C-0015, and DCA100-97-D-0025, the U.S. Government obtained 
--     unlimited rights in the software and documentation contained herein.
--     Unlimited rights are defined in DFAR 252.227-7013(a)(19).  By making 
--     this public release, the Government intends to confer upon all 
--     recipients unlimited rights  equal to those held by the Government.  
--     These rights include rights to use, duplicate, release or disclose the 
--     released technical data and computer software in whole or in part, in 
--     any manner and for any purpose whatsoever, and to have or permit others 
--     to do so.
--
--                                    DISCLAIMER
--
--     ALL MATERIALS OR INFORMATION HEREIN RELEASED, MADE AVAILABLE OR
--     DISCLOSED ARE AS IS.  THE GOVERNMENT MAKES NO EXPRESS OR IMPLIED 
--     WARRANTY AS TO ANY MATTER WHATSOEVER, INCLUDING THE CONDITIONS OF THE
--     SOFTWARE, DOCUMENTATION OR OTHER INFORMATION RELEASED, MADE AVAILABLE 
--     OR DISCLOSED, OR THE OWNERSHIP, MERCHANTABILITY, OR FITNESS FOR A
--     PARTICULAR PURPOSE OF SAID MATERIAL.
--*
-- CHECK THAT A SUBPROGRAM DECLARATION AND BODY CAN BE
-- SUBMITTED TOGETHER FOR COMPILATION.

-- JRK 5/14/81


FUNCTION CA1005A_F (I : INTEGER) RETURN INTEGER;


FUNCTION CA1005A_F (I : INTEGER) RETURN INTEGER IS
BEGIN
     RETURN I + 1;
END CA1005A_F;


PROCEDURE CA1005A_P (I : IN OUT INTEGER);


PROCEDURE CA1005A_P (I : IN OUT INTEGER) IS
BEGIN
     I := -I;
END CA1005A_P;


WITH REPORT, CA1005A_F, CA1005A_P;
USE REPORT;

PROCEDURE CA1005A IS

     I : INTEGER := IDENT_INT (7);

BEGIN
     TEST ("CA1005A", "SUBPROGRAM DECLARATIONS AND BODIES " &
           "SUBMITTED TOGETHER");

     IF CA1005A_F (IDENT_INT(2)) /= 3 THEN
          FAILED ("FUNCTION NOT EXECUTED");
     END IF;

     CA1005A_P (I);
     IF I /= -7 THEN
          FAILED ("PROCEDURE NOT EXECUTED");
     END IF;

     RESULT;
END CA1005A;
